<?php

namespace Litecms\KitchenBlog\Http\Controllers;

use App\Http\Controllers\APIController as BaseController;
use Litecms\KitchenBlog\Http\Requests\KitchenRequest;
use Litecms\KitchenBlog\Interfaces\KitchenRepositoryInterface;
use Litecms\KitchenBlog\Models\Kitchen;
use Litecms\KitchenBlog\Forms\Kitchen as Form;

/**
 * APIController  class for kitchen.
 */
class KitchenAPIController extends BaseController
{

    /**
     * Initialize kitchen resource controller.
     *
     * @param type KitchenRepositoryInterface $kitchen
     *
     * @return null
     */
    public function __construct(KitchenRepositoryInterface $kitchen)
    {
        parent::__construct();
        $this->repository = $kitchen;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Litecms\KitchenBlog\Repositories\Criteria\KitchenResourceCriteria::class);
    }

    /**
     * Display a list of kitchen.
     *
     * @return Response
     */
    public function index(KitchenRequest $request)
    {
        return $this->repository
            ->setPresenter(\Litecms\KitchenBlog\Repositories\Presenter\KitchenPresenter::class)
            ->paginate();
    }

    /**
     * Display kitchen.
     *
     * @param Request $request
     * @param Model   $kitchen
     *
     * @return Response
     */
    public function show(KitchenRequest $request, Kitchen $kitchen)
    {
        return $kitchen->setPresenter(\Litecms\KitchenBlog\Repositories\Presenter\KitchenListPresenter::class);
        ;
    }

    /**
     * Create new kitchen.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(KitchenRequest $request)
    {
        try {
            $data              = $request->all();
            $data['user_id']   = user_id();
            $data['user_type'] = user_type();
            $data              = $this->repository->create($data);
            $message           = trans('messages.success.created', ['Module' => trans('kitchen_blog::kitchen.name')]);
            $code              = 204;
            $status            = 'success';
            $url               = guard_url('kitchen_blog/kitchen/' . $kitchen->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('kitchen_blog/kitchen');
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Update the kitchen.
     *
     * @param Request $request
     * @param Model   $kitchen
     *
     * @return Response
     */
    public function update(KitchenRequest $request, Kitchen $kitchen)
    {
        try {
            $data = $request->all();

            $kitchen->update($data);
            $message = trans('messages.success.updated', ['Module' => trans('kitchen_blog::kitchen.name')]);
            $code    = 204;
            $status  = 'success';
            $url     = guard_url('kitchen_blog/kitchen/' . $kitchen->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('kitchen_blog/kitchen/' . $kitchen->getRouteKey());
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Remove the kitchen.
     *
     * @param Model   $kitchen
     *
     * @return Response
     */
    public function destroy(KitchenRequest $request, Kitchen $kitchen)
    {
        try {
            $kitchen->delete();
            $message = trans('messages.success.deleted', ['Module' => trans('kitchen_blog::kitchen.name')]);
            $code    = 202;
            $status  = 'success';
            $url     = guard_url('kitchen_blog/kitchen/0');
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('kitchen_blog/kitchen/' . $kitchen->getRouteKey());
        }
        return compact('message', 'code', 'status', 'url');
    }

    /**
     * Return the form elements as json.
     *
     * @param String   $element
     *
     * @return json
     */
    public function form($element = 'fields')
    {
        $form = new Form();
        return $form->form($element, true);
    }

}
