<?php

namespace Litecms\KitchenBlog\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Litecms\KitchenBlog\Http\Requests\KitchenCategoryRequest;
use Litecms\KitchenBlog\Models\KitchenCategory;

/**
 * Admin web controller class.
 */
class KitchenCategoryWorkflowController extends BaseController
{

    /**
     * Workflow controller function for kitchen_category.
     *
     * @param Model   $kitchen_category
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(KitchenCategoryRequest $request, KitchenCategory $kitchen_category, $step)
    {

        try {

            $kitchen_category->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('kitchen_blog::kitchen_category.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/kitchen_category/kitchen_category/' . $kitchen_category->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/kitchen_category/kitchen_category/' . $kitchen_category->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for kitchen_category.
     *
     * @param Model   $kitchen_category
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
     */

    public function getWorkflow(KitchenCategory $kitchen_category, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $kitchen_category->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('kitchen_blog::kitchen_category.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('kitchen_blog::admin.kitchen_category.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('kitchen_blog::admin.kitchen_category.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('kitchen_blog::admin.kitchen_category.message', $data)->render();

        }

    }
}
