<?php

namespace Litecms\KitchenBlog\Http\Controllers;

use App\Http\Controllers\APIController as BaseController;
use Litecms\KitchenBlog\Http\Requests\KitchenTagRequest;
use Litecms\KitchenBlog\Interfaces\KitchenTagRepositoryInterface;
use Litecms\KitchenBlog\Models\KitchenTag;
use Litecms\KitchenBlog\Forms\KitchenTag as Form;

/**
 * APIController  class for kitchen_tag.
 */
class KitchenTagAPIController extends BaseController
{

    /**
     * Initialize kitchen_tag resource controller.
     *
     * @param type KitchenTagRepositoryInterface $kitchen_tag
     *
     * @return null
     */
    public function __construct(KitchenTagRepositoryInterface $kitchen_tag)
    {
        parent::__construct();
        $this->repository = $kitchen_tag;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Litecms\KitchenBlog\Repositories\Criteria\KitchenTagResourceCriteria::class);
    }

    /**
     * Display a list of kitchen_tag.
     *
     * @return Response
     */
    public function index(KitchenTagRequest $request)
    {
        return $this->repository
            ->setPresenter(\Litecms\KitchenBlog\Repositories\Presenter\KitchenTagPresenter::class)
            ->paginate();
    }

    /**
     * Display kitchen_tag.
     *
     * @param Request $request
     * @param Model   $kitchen_tag
     *
     * @return Response
     */
    public function show(KitchenTagRequest $request, KitchenTag $kitchen_tag)
    {
        return $kitchen_tag->setPresenter(\Litecms\KitchenBlog\Repositories\Presenter\KitchenTagListPresenter::class);
        ;
    }

    /**
     * Create new kitchen_tag.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(KitchenTagRequest $request)
    {
        try {
            $data              = $request->all();
            $data['user_id']   = user_id();
            $data['user_type'] = user_type();
            $data              = $this->repository->create($data);
            $message           = trans('messages.success.created', ['Module' => trans('kitchen_blog::kitchen_tag.name')]);
            $code              = 204;
            $status            = 'success';
            $url               = guard_url('kitchen_blog/kitchen_tag/' . $kitchen_tag->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('kitchen_blog/kitchen_tag');
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Update the kitchen_tag.
     *
     * @param Request $request
     * @param Model   $kitchen_tag
     *
     * @return Response
     */
    public function update(KitchenTagRequest $request, KitchenTag $kitchen_tag)
    {
        try {
            $data = $request->all();

            $kitchen_tag->update($data);
            $message = trans('messages.success.updated', ['Module' => trans('kitchen_blog::kitchen_tag.name')]);
            $code    = 204;
            $status  = 'success';
            $url     = guard_url('kitchen_blog/kitchen_tag/' . $kitchen_tag->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('kitchen_blog/kitchen_tag/' . $kitchen_tag->getRouteKey());
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Remove the kitchen_tag.
     *
     * @param Model   $kitchen_tag
     *
     * @return Response
     */
    public function destroy(KitchenTagRequest $request, KitchenTag $kitchen_tag)
    {
        try {
            $kitchen_tag->delete();
            $message = trans('messages.success.deleted', ['Module' => trans('kitchen_blog::kitchen_tag.name')]);
            $code    = 202;
            $status  = 'success';
            $url     = guard_url('kitchen_blog/kitchen_tag/0');
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('kitchen_blog/kitchen_tag/' . $kitchen_tag->getRouteKey());
        }
        return compact('message', 'code', 'status', 'url');
    }

    /**
     * Return the form elements as json.
     *
     * @param String   $element
     *
     * @return json
     */
    public function form($element = 'fields')
    {
        $form = new Form();
        return $form->form($element, true);
    }

}
