<?php

namespace Litecms\KitchenBlog\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Litecms\KitchenBlog\Http\Requests\KitchenTagRequest;
use Litecms\KitchenBlog\Models\KitchenTag;

/**
 * Admin web controller class.
 */
class KitchenTagWorkflowController extends BaseController
{

    /**
     * Workflow controller function for kitchen_tag.
     *
     * @param Model   $kitchen_tag
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(KitchenTagRequest $request, KitchenTag $kitchen_tag, $step)
    {

        try {

            $kitchen_tag->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('kitchen_blog::kitchen_tag.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/kitchen_tag/kitchen_tag/' . $kitchen_tag->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/kitchen_tag/kitchen_tag/' . $kitchen_tag->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for kitchen_tag.
     *
     * @param Model   $kitchen_tag
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
     */

    public function getWorkflow(KitchenTag $kitchen_tag, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $kitchen_tag->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('kitchen_blog::kitchen_tag.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('kitchen_blog::admin.kitchen_tag.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('kitchen_blog::admin.kitchen_tag.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('kitchen_blog::admin.kitchen_tag.message', $data)->render();

        }

    }
}
