<?php

namespace Litecms\KitchenBlog\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\KitchenBlog\Models\KitchenComment;

class KitchenCommentPolicy
{

    /**
     * Determine if the given user can view the kitchen_comment.
     *
     * @param UserPolicy $user
     * @param KitchenComment $kitchen_comment
     *
     * @return bool
     */
    public function view(UserPolicy $user, KitchenComment $kitchen_comment)
    {
        if ($user->canDo('kitchen_blog.kitchen_comment.view') && $user->isAdmin()) {
            return true;
        }

        return $kitchen_comment->user_id == user_id() && $kitchen_comment->user_type == user_type();
    }

    /**
     * Determine if the given user can create a kitchen_comment.
     *
     * @param UserPolicy $user
     * @param KitchenComment $kitchen_comment
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('kitchen_blog.kitchen_comment.create');
    }

    /**
     * Determine if the given user can update the given kitchen_comment.
     *
     * @param UserPolicy $user
     * @param KitchenComment $kitchen_comment
     *
     * @return bool
     */
    public function update(UserPolicy $user, KitchenComment $kitchen_comment)
    {
        if ($user->canDo('kitchen_blog.kitchen_comment.edit') && $user->isAdmin()) {
            return true;
        }

        return $kitchen_comment->user_id == user_id() && $kitchen_comment->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given kitchen_comment.
     *
     * @param UserPolicy $user
     * @param KitchenComment $kitchen_comment
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, KitchenComment $kitchen_comment)
    {
        return $kitchen_comment->user_id == user_id() && $kitchen_comment->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given kitchen_comment.
     *
     * @param UserPolicy $user
     * @param KitchenComment $kitchen_comment
     *
     * @return bool
     */
    public function verify(UserPolicy $user, KitchenComment $kitchen_comment)
    {
        if ($user->canDo('kitchen_blog.kitchen_comment.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given kitchen_comment.
     *
     * @param UserPolicy $user
     * @param KitchenComment $kitchen_comment
     *
     * @return bool
     */
    public function approve(UserPolicy $user, KitchenComment $kitchen_comment)
    {
        if ($user->canDo('kitchen_blog.kitchen_comment.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
