<?php

namespace Litecms\KitchenBlog\Providers;

use Illuminate\Foundation\Support\Providers\RouteServiceProvider as ServiceProvider;
use Illuminate\Routing\Router;
use Litecms\KitchenBlog\Models\KitchenBlog;
use Request;
use Route;

class RouteServiceProvider extends ServiceProvider
{
    /**
     * This namespace is applied to the controller routes in your routes file.
     *
     * In addition, it is set as the URL generator's root namespace.
     *
     * @var string
     */
    protected $namespace = 'Litecms\KitchenBlog\Http\Controllers';

    /**
     * Define your route model bindings, pattern filters, etc.
     *
     * @param   \Illuminate\Routing\Router  $router
     * @return void
     */
    public function boot()
    {
        parent::boot();

        if (Request::is('*/kitchen_blog/kitchen/*')) {
            Route::bind('kitchen', function ($kitchen) {
                $kitchenrepo = $this->app->make('Litecms\KitchenBlog\Interfaces\KitchenRepositoryInterface');
                return $kitchenrepo->findorNew($kitchen);
            });
        }
        if (Request::is('*/kitchen_blog/kitchen_category/*')) {
            Route::bind('kitchen_category', function ($kitchen_category) {
                $kitchen_categoryrepo = $this->app->make('Litecms\KitchenBlog\Interfaces\KitchenCategoryRepositoryInterface');
                return $kitchen_categoryrepo->findorNew($kitchen_category);
            });
        }
        if (Request::is('*/kitchen_blog/kitchen_comment/*')) {
            Route::bind('kitchen_comment', function ($kitchen_comment) {
                $kitchen_commentrepo = $this->app->make('Litecms\KitchenBlog\Interfaces\KitchenCommentRepositoryInterface');
                return $kitchen_commentrepo->findorNew($kitchen_comment);
            });
        }
        if (Request::is('*/kitchen_blog/kitchen_tag/*')) {
            Route::bind('kitchen_tag', function ($kitchen_tag) {
                $kitchen_tagrepo = $this->app->make('Litecms\KitchenBlog\Interfaces\KitchenTagRepositoryInterface');
                return $kitchen_tagrepo->findorNew($kitchen_tag);
            });
        }

    }

    /**
     * Define the routes for the package.
     *
     * @return void
     */
    public function map()
    {
        $this->mapWebRoutes();

        $this->mapApiRoutes();
    }

    /**
     * Define the "web" routes for the package.
     *
     * These routes all receive session state, CSRF protection, etc.
     *
     * @return void
     */
    protected function mapWebRoutes()
    {   
        Route::group([
            'middleware' => 'web',
            'namespace'  => $this->namespace,
        ], function ($router) {
            require (__DIR__ . '/../../routes/web.php');
        });
    }

    /**
     * Define the "api" routes for the package.
     *
     * These routes are typically stateless.
     *
     * @return void
     */
    protected function mapApiRoutes()
    {
        Route::group([
            'middleware' => 'api',
            'namespace'  => $this->namespace,
            'prefix'     => 'api',
        ], function ($router) {
            require (__DIR__ . '/../../routes/api.php');
        });
    }

}
