<?php

namespace Litecms\KitchenBlog\Providers;

use Litepie\Contracts\Workflow\Workflow as WorkflowContract;
use Litepie\Foundation\Support\Providers\WorkflowServiceProvider as ServiceProvider;

class WorkflowServiceProvider extends ServiceProvider
{
    /**
     * The validators mappings for the package.
     *
     * @var array
     */
    protected $validators = [
        // Bind KitchenCategory workflow validator
        'Litecms\KitchenBlog\Models\KitchenCategory' => \Litecms\KitchenBlog\Workflow\KitchenCategoryValidator::class,
        // Bind KitchenComment workflow validator
        'Litecms\KitchenBlog\Models\KitchenComment' => \Litecms\KitchenBlog\Workflow\KitchenCommentValidator::class,
        // Bind KitchenTag workflow validator
        'Litecms\KitchenBlog\Models\KitchenTag' => \Litecms\KitchenBlog\Workflow\KitchenTagValidator::class,
    ];

    /**
     * The actions mappings for the package.
     *
     * @var array
     */
    protected $actions = [
        // Bind KitchenCategory workflow actions
        'Litecms\KitchenBlog\Models\KitchenCategory' => \Litecms\KitchenBlog\Workflow\KitchenCategoryAction::class,
        // Bind KitchenComment workflow actions
        'Litecms\KitchenBlog\Models\KitchenComment' => \Litecms\KitchenBlog\Workflow\KitchenCommentAction::class,
        // Bind KitchenTag workflow actions
        'Litecms\KitchenBlog\Models\KitchenTag' => \Litecms\KitchenBlog\Workflow\KitchenTagAction::class,
    ];

    /**
     * The notifiers mappings for the package.
     *
     * @var array
     */
    protected $notifiers = [
       // Bind KitchenCategory workflow notifiers
        'Litecms\KitchenBlog\Models\KitchenCategory' => \Litecms\KitchenBlog\Workflow\KitchenCategoryNotifier::class,
        // Bind KitchenComment workflow notifiers
        'Litecms\KitchenBlog\Models\KitchenComment' => \Litecms\KitchenBlog\Workflow\KitchenCommentNotifier::class,
        // Bind KitchenTag workflow notifiers
        'Litecms\KitchenBlog\Models\KitchenTag' => \Litecms\KitchenBlog\Workflow\KitchenTagNotifier::class,
    ];

    /**
     * Register any package workflow validation services.
     *
     * @param \Litepie\Contracts\Workflow\Workflow $workflow
     *
     * @return void
     */
    public function boot(WorkflowContract $workflow)
    {
        parent::registerValidators($workflow);
        parent::registerActions($workflow);
        parent::registerNotifiers($workflow);
    }
}
