<?php

namespace Litecms\KitchenBlog\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use Litecms\KitchenBlog\Models\KitchenCategory;

class KitchenCategoryAction
{
    /**
     * Perform the complete action.
     *
     * @param KitchenCategory $kitchen_category
     *
     * @return KitchenCategory
     */
    public function complete(KitchenCategory $kitchen_category)
    {
        try {
            $kitchen_category->status = 'complete';
            return $kitchen_category->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param KitchenCategory $kitchen_category
     *
     * @return KitchenCategory
     */public function verify(KitchenCategory $kitchen_category)
    {
        try {
            $kitchen_category->status = 'verify';
            return $kitchen_category->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param KitchenCategory $kitchen_category
     *
     * @return KitchenCategory
     */public function approve(KitchenCategory $kitchen_category)
    {
        try {
            $kitchen_category->status = 'approve';
            return $kitchen_category->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param KitchenCategory $kitchen_category
     *
     * @return KitchenCategory
     */public function publish(KitchenCategory $kitchen_category)
    {
        try {
            $kitchen_category->status = 'publish';
            return $kitchen_category->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param KitchenCategory $kitchen_category
     *
     * @return KitchenCategory
     */
    public function archive(KitchenCategory $kitchen_category)
    {
        try {
            $kitchen_category->status = 'archive';
            return $kitchen_category->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param KitchenCategory $kitchen_category
     *
     * @return KitchenCategory
     */
    public function unpublish(KitchenCategory $kitchen_category)
    {
        try {
            $kitchen_category->status = 'unpublish';
            return $kitchen_category->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
