<?php

namespace Litecms\KitchenBlog\Workflow;

use Litecms\KitchenBlog\Models\KitchenCategory;
use Validator;

class KitchenCategoryValidator
{

    /**
     * Determine if the given kitchen_category is valid for complete status.
     *
     * @param KitchenCategory $kitchen_category
     *
     * @return bool / Validator
     */
    public function complete(KitchenCategory $kitchen_category)
    {
        return Validator::make($kitchen_category->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given kitchen_category is valid for verify status.
     *
     * @param KitchenCategory $kitchen_category
     *
     * @return bool / Validator
     */
    public function verify(KitchenCategory $kitchen_category)
    {
        return Validator::make($kitchen_category->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given kitchen_category is valid for approve status.
     *
     * @param KitchenCategory $kitchen_category
     *
     * @return bool / Validator
     */
    public function approve(KitchenCategory $kitchen_category)
    {
        return Validator::make($kitchen_category->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given kitchen_category is valid for publish status.
     *
     * @param KitchenCategory $kitchen_category
     *
     * @return bool / Validator
     */
    public function publish(KitchenCategory $kitchen_category)
    {
        return Validator::make($kitchen_category->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given kitchen_category is valid for archive status.
     *
     * @param KitchenCategory $kitchen_category
     *
     * @return bool / Validator
     */
    public function archive(KitchenCategory $kitchen_category)
    {
        return Validator::make($kitchen_category->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given kitchen_category is valid for unpublish status.
     *
     * @param KitchenCategory $kitchen_category
     *
     * @return bool / Validator
     */
    public function unpublish(KitchenCategory $kitchen_category)
    {
        return Validator::make($kitchen_category->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
