<?php

namespace Litecms\KitchenBlog\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use Litecms\KitchenBlog\Models\KitchenComment;

class KitchenCommentAction
{
    /**
     * Perform the complete action.
     *
     * @param KitchenComment $kitchen_comment
     *
     * @return KitchenComment
     */
    public function complete(KitchenComment $kitchen_comment)
    {
        try {
            $kitchen_comment->status = 'complete';
            return $kitchen_comment->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param KitchenComment $kitchen_comment
     *
     * @return KitchenComment
     */public function verify(KitchenComment $kitchen_comment)
    {
        try {
            $kitchen_comment->status = 'verify';
            return $kitchen_comment->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param KitchenComment $kitchen_comment
     *
     * @return KitchenComment
     */public function approve(KitchenComment $kitchen_comment)
    {
        try {
            $kitchen_comment->status = 'approve';
            return $kitchen_comment->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param KitchenComment $kitchen_comment
     *
     * @return KitchenComment
     */public function publish(KitchenComment $kitchen_comment)
    {
        try {
            $kitchen_comment->status = 'publish';
            return $kitchen_comment->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param KitchenComment $kitchen_comment
     *
     * @return KitchenComment
     */
    public function archive(KitchenComment $kitchen_comment)
    {
        try {
            $kitchen_comment->status = 'archive';
            return $kitchen_comment->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param KitchenComment $kitchen_comment
     *
     * @return KitchenComment
     */
    public function unpublish(KitchenComment $kitchen_comment)
    {
        try {
            $kitchen_comment->status = 'unpublish';
            return $kitchen_comment->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
