<?php

namespace Litecms\KitchenBlog\Workflow;

use Litecms\KitchenBlog\Models\KitchenComment;
use Validator;

class KitchenCommentValidator
{

    /**
     * Determine if the given kitchen_comment is valid for complete status.
     *
     * @param KitchenComment $kitchen_comment
     *
     * @return bool / Validator
     */
    public function complete(KitchenComment $kitchen_comment)
    {
        return Validator::make($kitchen_comment->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given kitchen_comment is valid for verify status.
     *
     * @param KitchenComment $kitchen_comment
     *
     * @return bool / Validator
     */
    public function verify(KitchenComment $kitchen_comment)
    {
        return Validator::make($kitchen_comment->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given kitchen_comment is valid for approve status.
     *
     * @param KitchenComment $kitchen_comment
     *
     * @return bool / Validator
     */
    public function approve(KitchenComment $kitchen_comment)
    {
        return Validator::make($kitchen_comment->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given kitchen_comment is valid for publish status.
     *
     * @param KitchenComment $kitchen_comment
     *
     * @return bool / Validator
     */
    public function publish(KitchenComment $kitchen_comment)
    {
        return Validator::make($kitchen_comment->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given kitchen_comment is valid for archive status.
     *
     * @param KitchenComment $kitchen_comment
     *
     * @return bool / Validator
     */
    public function archive(KitchenComment $kitchen_comment)
    {
        return Validator::make($kitchen_comment->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given kitchen_comment is valid for unpublish status.
     *
     * @param KitchenComment $kitchen_comment
     *
     * @return bool / Validator
     */
    public function unpublish(KitchenComment $kitchen_comment)
    {
        return Validator::make($kitchen_comment->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
