<?php

namespace Litecms\KitchenBlog\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use Litecms\KitchenBlog\Models\KitchenTag;

class KitchenTagAction
{
    /**
     * Perform the complete action.
     *
     * @param KitchenTag $kitchen_tag
     *
     * @return KitchenTag
     */
    public function complete(KitchenTag $kitchen_tag)
    {
        try {
            $kitchen_tag->status = 'complete';
            return $kitchen_tag->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param KitchenTag $kitchen_tag
     *
     * @return KitchenTag
     */public function verify(KitchenTag $kitchen_tag)
    {
        try {
            $kitchen_tag->status = 'verify';
            return $kitchen_tag->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param KitchenTag $kitchen_tag
     *
     * @return KitchenTag
     */public function approve(KitchenTag $kitchen_tag)
    {
        try {
            $kitchen_tag->status = 'approve';
            return $kitchen_tag->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param KitchenTag $kitchen_tag
     *
     * @return KitchenTag
     */public function publish(KitchenTag $kitchen_tag)
    {
        try {
            $kitchen_tag->status = 'publish';
            return $kitchen_tag->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param KitchenTag $kitchen_tag
     *
     * @return KitchenTag
     */
    public function archive(KitchenTag $kitchen_tag)
    {
        try {
            $kitchen_tag->status = 'archive';
            return $kitchen_tag->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param KitchenTag $kitchen_tag
     *
     * @return KitchenTag
     */
    public function unpublish(KitchenTag $kitchen_tag)
    {
        try {
            $kitchen_tag->status = 'unpublish';
            return $kitchen_tag->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
