<?php

namespace Litecms\KitchenBlog\Workflow;

use Litecms\KitchenBlog\Models\KitchenTag;
use Validator;

class KitchenTagValidator
{

    /**
     * Determine if the given kitchen_tag is valid for complete status.
     *
     * @param KitchenTag $kitchen_tag
     *
     * @return bool / Validator
     */
    public function complete(KitchenTag $kitchen_tag)
    {
        return Validator::make($kitchen_tag->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given kitchen_tag is valid for verify status.
     *
     * @param KitchenTag $kitchen_tag
     *
     * @return bool / Validator
     */
    public function verify(KitchenTag $kitchen_tag)
    {
        return Validator::make($kitchen_tag->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given kitchen_tag is valid for approve status.
     *
     * @param KitchenTag $kitchen_tag
     *
     * @return bool / Validator
     */
    public function approve(KitchenTag $kitchen_tag)
    {
        return Validator::make($kitchen_tag->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given kitchen_tag is valid for publish status.
     *
     * @param KitchenTag $kitchen_tag
     *
     * @return bool / Validator
     */
    public function publish(KitchenTag $kitchen_tag)
    {
        return Validator::make($kitchen_tag->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given kitchen_tag is valid for archive status.
     *
     * @param KitchenTag $kitchen_tag
     *
     * @return bool / Validator
     */
    public function archive(KitchenTag $kitchen_tag)
    {
        return Validator::make($kitchen_tag->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given kitchen_tag is valid for unpublish status.
     *
     * @param KitchenTag $kitchen_tag
     *
     * @return bool / Validator
     */
    public function unpublish(KitchenTag $kitchen_tag)
    {
        return Validator::make($kitchen_tag->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
